Release history
===============

Version 0.7.2
--------------

- Improve logging messages.
- Do not double include files in sdist that are selected in includes, extra and metadata files.


Version 0.7.1
--------------

- Simplify how includes and excludes are processed.
- Make builds reproducible.
- Add support to run arbitrarry Python scripts at the start of a wheel or sdist build.
- Improve documentation, including a release checklist.


Version 0.6.2
--------------

- First working version.


Version 0.6.1
--------------

- Improve documentation.


Version 0.6.0
--------------

- Work in progress.


Version 0.5
-----------

- Initial release forked from flit.
